@@ -110,8 +110,11 @@ net_richclub <- function(.data){
 net_factions <- function(.data,
                        membership = NULL){
   if(missing(.data)) {expect_nodes(); .data <- .G()}
-  if(is.null(membership))
+  if(is.null(membership)){
+    mnet_info("No membership vector assigned.",
+              "Partitioning the network using {.fn node_in_partition}.")
     membership <- node_in_partition(.data)
+  }
   out <- stats::cor(c(manynet::as_matrix(.data)), 
                     c(manynet::as_matrix(manynet::create_components(.data,
                                                   membership = membership))))
@@ -135,8 +138,12 @@ net_factions <- function(.data,
 #'   can miss small clusters that 'hide' inside larger clusters.
 #'   In the extreme case, this can be where they are only connected
 #'   to the rest of the network through a single tie.
+#'   To help manage this problem, a `resolution` parameter is added. 
+#'   Please see the argument definition for more details.
 #' @param resolution A proportion indicating the resolution scale.
-#'   By default 1.
+#'   By default 1, which returns the original definition of modularity.
+#'   The higher this parameter, the more smaller communities will be privileged.
+#'   The lower this parameter, the fewer larger communities are likely to be found.
 #' @examples 
 #' net_modularity(ison_adolescents, 
 #'   node_in_partition(ison_adolescents))
